OC.L10N.register(
    "dav",
    {
    "Calendar" : "يىلنامە",
    "Tasks" : "ۋەزىپەلەر",
    "Personal" : "شەخسىي",
    "{actor} created calendar {calendar}" : "{actor} قۇرغان كالېندار {calendar}",
    "You created calendar {calendar}" : "كالېندار {calendar} قۇردىڭىز",
    "{actor} deleted calendar {calendar}" : "{actor} ئۆچۈرۈلگەن كالېندار {calendar}",
    "You deleted calendar {calendar}" : "كالېندار {calendar} ئۆچۈردىڭىز",
    "{actor} updated calendar {calendar}" : "{actor} يېڭىلانغان كالېندار {calendar}",
    "You updated calendar {calendar}" : "كالېندار {calendar} يېڭىلىدىڭىز",
    "{actor} restored calendar {calendar}" : "{actor} ئەسلىگە كەلتۈرۈلگەن كالېندار {calendar}",
    "You restored calendar {calendar}" : "كالېندار {calendar} ئەسلىگە كەلتۈردىڭىز",
    "You shared calendar {calendar} as public link" : "سىز كالېندار {calendar} public نى ئاممىۋى ئۇلىنىش سۈپىتىدە ھەمبەھىرلىدىڭىز",
    "You removed public link for calendar {calendar}" : "كالېندار {calendar} ئۈچۈن ئاممىۋى ئۇلىنىشنى ئۆچۈردىڭىز",
    "{actor} shared calendar {calendar} with you" : "{actor} ئورتاقلاشقان كالېندار {calendar} سىز بىلەن",
    "You shared calendar {calendar} with {user}" : "سىز كالېندار {calendar} نى {user} بىلەن ئورتاقلاشتىڭىز",
    "{actor} shared calendar {calendar} with {user}" : "{actor} ئورتاقلاشقان كالېندار {calendar} {user} بىلەن",
    "{actor} unshared calendar {calendar} from you" : "{actor} ئورتاقلاشمىغان كالېندار {calendar} سىزدىن",
    "You unshared calendar {calendar} from {user}" : "سىز كالىندار {calendar} نى {user} دىن ھەمبەرلەنمىدىڭىز",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} ئورتاقلاشمىغان كالېندار {calendar} {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} ئورتاقلاشمىغان كالېندار {calendar} ئۆزىدىن",
    "You shared calendar {calendar} with group {group}" : "كالېندار {calendar} group گۇرۇپپا {group} بىلەن ئورتاقلاشتىڭىز",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} گۇرۇپپا {calendar} بىلەن ئورتاقلاشقان كالېندار {group}",
    "You unshared calendar {calendar} from group {group}" : "گۇرۇپپا {calendar} ئورتاقلاشمىغان كالېندار {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} بولسا كالىندار {calendar} نى گۇرۇپپا {group} بىلەن ھەمبەھىرلىمىدى",
    "Untitled event" : "نامسىز ھادىسە",
    "{actor} created event {event} in calendar {calendar}" : "{actor} كالېندار {event} پائالىيەت {calendar} قۇرغان}",
    "You created event {event} in calendar {calendar}" : "كالېندار {event} پائالىيەت {calendar} created قۇردىڭىز",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} ئۆچۈرۈلگەن ھادىسە {event} كالېنداردىن {calendar}",
    "You deleted event {event} from calendar {calendar}" : "كالېندار {event} ھادىسە {calendar} ئۆچۈردىڭىز",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} بولسا كالىندار {calendar} دىكى پائالىيەت {event} نى يېڭىلىدى",
    "You updated event {event} in calendar {calendar}" : "كالېندار {event} پائالىيەت {calendar} نى يېڭىلىدىڭىز",
    "{actor} moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "{actor} پائالىيەت {event} كالېنداردىن {sourceCalendar} دىن كالېندارغا {targetCalendar} غا يۆتكەلدى",
    "You moved event {event} from calendar {sourceCalendar} to calendar {targetCalendar}" : "سىز ھادىسە {event} كالىندارىدىن {sourceCalendar} دىن كالېندار {targetCalendar} غا يۆتكىدىڭىز",
    "{actor} restored event {event} of calendar {calendar}" : "{actor} ئەسلىگە كەلتۈرۈلگەن ھادىسە {event} كالىندارى {calendar}",
    "You restored event {event} of calendar {calendar}" : "كالېندار {event} پائالىيەت {calendar} نى ئەسلىگە كەلتۈردىڭىز",
    "Busy" : "ئالدىراش",
    "{actor} created to-do {todo} in list {calendar}" : "{actor} list تىزىملىك {calendar} {todo} ئىجاد قىلىش",
    "You created to-do {todo} in list {calendar}" : "سىز تىزىملىك {calendar} {todo} نى قۇردىڭىز",
    "{actor} deleted to-do {todo} from list {calendar}" : "{actor} list تىزىملىكتىن {calendar} to ئۆچۈرۈلدى {todo}",
    "You deleted to-do {todo} from list {calendar}" : "تىزىملىكتىن {todo} to نى ئۆچۈردىڭىز {calendar}",
    "{actor} updated to-do {todo} in list {calendar}" : "{actor} تىزىملىك {calendar} {todo} يېڭىلانغان",
    "You updated to-do {todo} in list {calendar}" : "تىزىملىك {calendar} دىكى {todo} نى يېڭىلىدىڭىز",
    "{actor} solved to-do {todo} in list {calendar}" : "{actor} بولسا {calendar} تىزىملىكتىكى  {todo} نى ھەل قىلدى",
    "You solved to-do {todo} in list {calendar}" : "تىزىملىك {calendar} دىكى {todo} نى ھەل قىلدىڭىز",
    "{actor} reopened to-do {todo} in list {calendar}" : "{actor} تىزىملىك {calendar} {todo} قايتا ئېچىلدى",
    "You reopened to-do {todo} in list {calendar}" : "تىزىملىك {calendar} دىكى {todo} نى قايتا ئاچتىڭىز",
    "Calendar, contacts and tasks" : "كالېندار ، ئالاقىلىشىش ۋە ۋەزىپە",
    "A <strong>calendar</strong> was modified" : "<strong> كالېندار </ strong> ئۆزگەرتىلدى",
    "A calendar <strong>event</strong> was modified" : "كالېندار <strong> ھادىسە </ strong> ئۆزگەرتىلدى",
    "A calendar <strong>to-do</strong> was modified" : "كالېندار <strong> قىلىش </ strong> ئۆزگەرتىلدى",
    "Contact birthdays" : "تۇغۇلغان كۈنى بىلەن ئالاقىلىشىڭ",
    "Death of %s" : "% S نىڭ ئۆلۈمى",
    "Untitled calendar" : "نامسىز كالېندار",
    "Calendar:" : "كالېندار:",
    "Date:" : "چېسلا:",
    "Where:" : "قەيەردە:",
    "Description:" : "چۈشەندۈرۈش:",
    "%s (in %s)" : "% s (% s)",
    "%s (%s ago)" : "% s (% s ago)",
    "Calendar: %s" : "كالېندار:% s",
    "Date: %s" : "چېسلا:% s",
    "Description: %s" : "چۈشەندۈرۈش:% s",
    "Where: %s" : "قەيەردە:% s",
    "%1$s via %2$s" : "%1 $ s ئارقىلىق%2 $ s",
    "Could not generate when statement" : "بايان قىلغاندا ھاسىل قىلالمىدى",
    "Every Day for the entire day" : "ھەر بىر كۈن پۈتۈن بىر كۈن",
    "Every Day for the entire day until %1$s" : "ھەر بىر كۈن پۈتۈن كۈن%1 $ s غىچە",
    "Every Day between %1$s - %2$s" : "ھەر كۈنى%1 $ s -%2 $ s ئارىلىقىدا",
    "Every Day between %1$s - %2$s until %3$s" : "ھەر كۈنى%1 $ s -%2 $ s ئارىلىقىدا%3 $ s غىچە",
    "Every %1$d Days for the entire day" : "پۈتۈن%1 $ d كۈن",
    "Every %1$d Days for the entire day until %2$s" : "ھەر%1 $ d پۈتۈن بىر كۈن ئىچىدە%2 $ s غىچە",
    "Every %1$d Days between %2$s - %3$s" : "ھەر%1 $ d كۈنلەر%2 $ s -%3 $ s ئارىلىقىدا",
    "Every %1$d Days between %2$s - %3$s until %4$s" : "ھەر%1 $ d كۈنلىرى%2 $ s -%3 $ s ئارىلىقىدا%4 $ s غىچە",
    "Could not generate event recurrence statement" : "ھادىسە قايتا-قايتا بايانات ھاسىل قىلالمىدى",
    "Every Week on %1$s for the entire day" : "ھەر ھەپتە پۈتۈن كۈن ئۈچۈن%1 $ s",
    "Every Week on %1$s for the entire day until %2$s" : "ھەر ھەپتە%1 $ s پۈتۈن بىر كۈن ئىچىدە%2 $ s غىچە",
    "Every Week on %1$s between %2$s - %3$s" : "ھەر ھەپتە%1 $ s دىكى%2 $ s -%3 $ s ئارىلىقىدا",
    "Every Week on %1$s between %2$s - %3$s until %4$s" : "ھەر ھەپتە%1 $ s دىكى%2 $ s -%3 $ s ئارىلىقىدا%4 $ s غىچە",
    "Every %1$d Weeks on %2$s for the entire day" : "پۈتۈن%1 $ d ھەپتىلىك%2 $ s",
    "Every %1$d Weeks on %2$s for the entire day until %3$s" : "ھەر%1 $ d ھەپتىلىك%2 $ s پۈتۈن بىر كۈن ئىچىدە%3 $ s غىچە",
    "Every %1$d Weeks on %2$s between %3$s - %4$s" : "ھەر%1 $ d ھەپتىلىك%2 $ s دىكى%3 $ s -%4 $ s ئارىلىقىدا",
    "Every %1$d Weeks on %2$s between %3$s - %4$s until %5$s" : "ھەر%1 $ d ھەپتىلىكى%2 $ s دىكى%3 $ s -%4 $ s ئارىلىقىدا%5 $ s گىچە",
    "Every Month on the %1$s for the entire day" : "ھەر ئايدا%1 $ s پۈتۈن بىر كۈن",
    "Every Month on the %1$s for the entire day until %2$s" : "ھەر ئايدا%1 $ s پۈتۈن بىر كۈن ئىچىدە%2 $ s غىچە",
    "Every Month on the %1$s between %2$s - %3$s" : "ھەر ئايدا%1 $ s دىكى%2 $ s -%3 $ s ئارىلىقىدا",
    "Every Month on the %1$s between %2$s - %3$s until %4$s" : "ھەر ئايدا%1 $ s دىكى%2 $ s -%3 $ s ئارىلىقىدا%4 $ s غىچە",
    "Every %1$d Months on the %2$s for the entire day" : "ھەر%1 $ d ئايلار پۈتۈن كۈندىكى%2 $ s",
    "Every %1$d Months on the %2$s for the entire day until %3$s" : "ھەر%1 $ d ئايلار%2 $ s پۈتۈن بىر كۈن ئىچىدە%3 $ s غىچە",
    "Every %1$d Months on the %2$s between %3$s - %4$s" : "ھەر%1 $ d ئايلار%2 $ s دىكى%3 $ s -%4 $ s ئارىلىقىدا",
    "Every %1$d Months on the %2$s between %3$s - %4$s until %5$s" : "ھەر%1 $ d ئايلار%2 $ s دىكى%3 $ s -%4 $ s ئارىلىقىدا%5 $ s غىچە",
    "Every Year in %1$s on the %2$s for the entire day" : "ھەر يىلى%1 $ s دىكى%2 $ s پۈتۈن بىر كۈن",
    "Every Year in %1$s on the %2$s for the entire day until %3$s" : "ھەر يىلى%1 $ s دىكى%2 $ s پۈتۈن بىر كۈن ئىچىدە%3 $ s غىچە",
    "Every Year in %1$s on the %2$s between %3$s - %4$s" : "ھەر يىلى%1 $ s دىكى%2 $ s دىكى%3 $ s -%4 $ s ئارىلىقىدا",
    "Every Year in %1$s on the %2$s between %3$s - %4$s until %5$s" : "ھەر يىلى%1 $ s دىكى%2 $ s دىكى%3 $ s -%4 $ s ئارىلىقىدا%5 $ s غىچە",
    "Every %1$d Years in %2$s on the %3$s for the entire day" : "ھەر%1 $ d يىللار%2 $ s دىكى پۈتۈن كۈن%3 $ s",
    "Every %1$d Years in %2$s on the %3$s for the entire day until %4$s" : "ھەر%1 $ d يىللار%2 $ s يىل ئىچىدە%3 $ s پۈتۈن بىر كۈن ئىچىدە%4 $ s غىچە",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s" : "ھەر%1 $ d يىللار%2 $ s دىكى%3 $ s دىكى%4 $ s -%5 $ s",
    "Every %1$d Years in %2$s on the %3$s between %4$s - %5$s until %6$s" : "ھەر%1 $ d يىللار%2 $ s دىكى%3 $ s دىكى%4 $ s -%5 $ s ئارىلىقىدىكى%6 $ s",
    "On specific dates for the entire day until %1$s" : "پۈتۈن كۈندىكى كونكرېت كۈنلەردە%1 $ s غىچە",
    "On specific dates between %1$s - %2$s until %3$s" : "كونكرېت كۈنلەردە%1 $ s -%2 $ s ئارىلىقىدا%3 $ s غىچە",
    "Could not generate next recurrence statement" : "كېيىنكى تەكرارلىنىش باياناتىنى ھاسىل قىلالمىدى",
    "Cancelled: %1$s" : "ئەمەلدىن قالدۇرۇلدى:%1 $ s",
    "\"%1$s\" has been canceled" : "\"%1 $ s\" ئەمەلدىن قالدۇرۇلدى",
    "Re: %1$s" : "Re:%1 $ s",
    "%1$s has accepted your invitation" : "%1 $ s سىزنىڭ تەكلىۋىڭىزنى قوبۇل قىلدى",
    "%1$s has tentatively accepted your invitation" : "%1 $ s سىزنىڭ تەكلىۋىڭىزنى ۋاقتىنچە قوبۇل قىلدى",
    "%1$s has declined your invitation" : "%1 $ s سىزنىڭ تەكلىۋىڭىزنى رەت قىلدى",
    "%1$s has responded to your invitation" : "%1 $ s سىزنىڭ تەكلىۋىڭىزگە جاۋاب قايتۇردى",
    "Invitation updated: %1$s" : "تەكلىپ يېڭىلاندى:%1 $ s",
    "%1$s updated the event \"%2$s\"" : "%1 $ s پائالىيەتنى \"%2 $ s\" يېڭىلىدى",
    "Invitation: %1$s" : "تەكلىپ:%1 $ s",
    "%1$s would like to invite you to \"%2$s\"" : "%1 $ s سىزنى «%2 $ s» غا تەكلىپ قىلماقچى",
    "Organizer:" : "تەشكىللىگۈچى:",
    "Attendees:" : "قاتناشقۇچىلار:",
    "Title:" : "ماۋزۇ:",
    "When:" : "قاچان:",
    "Location:" : "ئورنى:",
    "Link:" : "ئۇلىنىش:",
    "Occurring:" : "يۈز بەرگەن ئىشلار:",
    "Accept" : "قوبۇل قىلىڭ",
    "Decline" : "رەت قىلىش",
    "More options …" : "تېخىمۇ كۆپ تاللاشلار…",
    "More options at %s" : "% S دىكى تېخىمۇ كۆپ تاللاشلار",
    "Monday" : "دۈشەنبە",
    "Tuesday" : "سەيشەنبە",
    "Wednesday" : "چارشەنبە",
    "Thursday" : "پەيشەنبە",
    "Friday" : "جۈمە",
    "Saturday" : "شەنبە",
    "Sunday" : "يەكشەنبە",
    "January" : "قەھرىتان",
    "February" : "ھۇت",
    "March" : "نەۋرۇز",
    "April" : "ئۇمۇت",
    "May" : "باھار",
    "June" : "سەپەر",
    "July" : "چىللە",
    "August" : "تومۇز",
    "September" : "مىزان",
    "October" : "ئوغۇز",
    "November" : "ئوغلاق",
    "December" : "كۆنەك",
    "First" : "بىرىنچى",
    "Second" : "ئىككىنچى",
    "Third" : "ئۈچىنچىسى",
    "Fourth" : "تۆتىنچى",
    "Last" : "ئاخىرقى",
    "Second Last" : "Second Last",
    "Third Last" : "ئۈچىنچى ئاخىرقى",
    "Fourth Last" : "تۆتىنچى ئاخىرقى",
    "Contacts" : "ئالاقەداشلار",
    "{actor} created address book {addressbook}" : "{actor} قۇرغان ئادرېس دەپتىرى {addressbook} دەپتىرى}",
    "You created address book {addressbook}" : "سىز ئادرېس دەپتىرى {addressbook} دەپتىرىنى قۇردىڭىز",
    "{actor} deleted address book {addressbook}" : "{actor} ئۆچۈرۈلگەن ئادرېس دەپتىرى {addressbook} دەپتىرى}",
    "You deleted address book {addressbook}" : "سىز ئادرېس دەپتىرىنى {addressbook} دەپتىرىنى ئۆچۈردىڭىز",
    "{actor} updated address book {addressbook}" : "{actor} يېڭىلانغان ئادرېس دەپتىرى {addressbook} دەپتىرى}",
    "You updated address book {addressbook}" : "سىز ئادرېس دەپتىرىنى {addressbook} دەپتىرىنى يېڭىلىدىڭىز",
    "{actor} shared address book {addressbook} with you" : "{actor} ئورتاقلاشقان ئادرېس دەپتىرى {addressbook} دەپتىرى you سىز بىلەن",
    "You shared address book {addressbook} with {user}" : "سىز ئادرېس دەپتىرى {addressbook} دەپتىرىنى {user} بىلەن ئورتاقلاشتىڭىز",
    "{actor} shared address book {addressbook} with {user}" : "{actor} ئورتاقلاشقان ئادرېس دەپتىرى {addressbook} دەپتىرى {user}",
    "{actor} unshared address book {addressbook} from you" : "{actor} ئورتاقلاشمىغان ئادرېس دەپتىرى {addressbook} دەپتىرى you سىزدىن",
    "You unshared address book {addressbook} from {user}" : "سىز ئورتاق ئىشلەتمىگەن ئادرېس دەپتىرى {addressbook} دەپتىرى {user}",
    "{actor} unshared address book {addressbook} from {user}" : "{actor} ھەمبەھىرلەنمىگەن ئادرېس دەپتىرى {addressbook} دەپتىرى {user}",
    "{actor} unshared address book {addressbook} from themselves" : "{actor} ئورتاقلاشمىغان ئادرېس دەپتىرى {addressbook} دەپتىرى themselves ئۆزىدىن",
    "You shared address book {addressbook} with group {group}" : "گۇرۇپپا {addressbook} with بىلەن ئادرېس دەپتىرى {group} دەپتىرىنى ئورتاقلاشتىڭىز",
    "{actor} shared address book {addressbook} with group {group}" : "{actor} گۇرۇپپا {addressbook} بىلەن ئورتاقلاشقان ئادرېس دەپتىرى {group} دەپتىرى}",
    "You unshared address book {addressbook} from group {group}" : "گۇرۇپپا {addressbook} ھەمبەھىرلەنگەن ئادرېس دەپتىرى {group} دەپتىرى}",
    "{actor} unshared address book {addressbook} from group {group}" : "{actor} ئورتاق بەھرىلىنىدىغان ئادرېس دەپتىرى {addressbook} دەپتىرى group گۇرۇپپا {group}",
    "You created contact {card} in address book {addressbook}" : "سىز ئادرېس دەپتىرى {card} دەپتىرىدە ئالاقىلىشىش {addressbook} قۇردىڭىز",
    "{actor} deleted contact {card} from address book {addressbook}" : "{actor} contact ئادرېس دەپتىرى {card} دەپتىرىدىن ئالاقىلىشىش {addressbook} ئۆچۈرۈلگەن",
    "You deleted contact {card} from address book {addressbook}" : "ئالاقىلىشىش {card} address ئادرېس دەپتىرى {addressbook} دەپتىرىدىن ئۆچۈرۈلدىڭىز",
    "{actor} updated contact {card} in address book {addressbook}" : "{actor} يېڭىلانغان ئالاقىلىشىش {card} address ئادرېس دەپتىرى {addressbook} دەپتىرى}",
    "You updated contact {card} in address book {addressbook}" : "ئالاقىلىشىش {card} address ئادرېس دەپتىرى {addressbook} دەپتىرىنى يېڭىلىدىڭىز",
    "A <strong>contact</strong> or <strong>address book</strong> was modified" : "<strong> ئالاقىلىشىش </ strong> ياكى <strong> ئادرېس دەپتىرى </ strong> ئۆزگەرتىلدى",
    "Accounts" : "ھېسابات",
    "System address book which holds all accounts" : "بارلىق ھېساباتلارنى ئۆز ئىچىگە ئالغان سىستېما ئادرېس دەپتىرى",
    "File is not updatable: %1$s" : "ھۆججەت يېڭىلانمايدۇ:%1 $ s",
    "Failed to get storage for file" : "ھۆججەت ساقلاشقا ئېرىشەلمىدى",
    "Could not write to final file, canceled by hook" : "ئاخىرقى ھۆججەتكە يازالمىدى ، قارماق تەرىپىدىن ئەمەلدىن قالدۇرۇلدى",
    "Could not write file contents" : "ھۆججەت مەزمۇنىنى يازالمىدى",
    "Error while copying file to target location (copied: %1$s, expected filesize: %2$s)" : "نىشاننى نىشانغا كۆچۈرگەندە خاتالىق (كۆچۈرۈلگەن:%1 $ s ، مۆلچەردىكى ھۆججەتلەر:%2 $ s)",
    "Expected filesize of %1$s but read (from Nextcloud client) and wrote (to Nextcloud storage) %2$s. Could either be a network problem on the sending side or a problem writing to the storage on the server side." : "مۆلچەردىكى ھۆججەتلەر%1 $ s بولىدۇ ، ئەمما ئوقۇڭ (Nextcloud خېرىدارىدىن) ۋە (Nextcloud ساقلىغۇچقا)%2 $ s دەپ يازدى. ئەۋەتىش تەرەپتىكى تور مەسىلىسى ياكى مۇلازىمېتىر تەرەپتىكى ساقلاشقا يېزىش مەسىلىسى بولۇشى مۇمكىن.",
    "Could not rename part file to final file, canceled by hook" : "بۆلەك ھۆججىتىنى ئاخىرقى ھۆججەتكە ئۆزگەرتەلمىدى ، قارماق تەرىپىدىن ئەمەلدىن قالدۇرۇلدى",
    "Could not rename part file to final file" : "قىسمەن ھۆججەتنى ئاخىرقى ھۆججەتكە ئۆزگەرتەلمىدى",
    "Failed to check file size: %1$s" : "ھۆججەتنىڭ چوڭ-كىچىكلىكىنى تەكشۈرەلمىدى:%1 $ s",
    "Encryption not ready: %1$s" : "شىفىرلاش تەييار ئەمەس:%1 $ s",
    "Failed to open file: %1$s" : "ھۆججەت ئېچىلمىدى:%1 $ s",
    "Failed to unlink: %1$s" : "ئۇلانمىدى:%1 $ s",
    "Failed to write file contents: %1$s" : "ھۆججەت مەزمۇنىنى يېزىش مەغلۇب بولدى:%1 $ s",
    "File not found: %1$s" : "ھۆججەت تېپىلمىدى:%1 $ s",
    "Invalid target path" : "نىشان يولى ئىناۋەتسىز",
    "System is in maintenance mode." : "سىستېما ئاسراش ھالىتىدە.",
    "Upgrade needed" : "يېڭىلاش كېرەك",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "IOS / macOS ئارقىلىق CalDAV ۋە CardDAV نى ئىشلىتىش ئۈچۈن% s نى HTTPS ئىشلىتىش ئۈچۈن تەڭشەش كېرەك.",
    "Configures a CalDAV account" : "CalDAV ھېساباتىنى سەپلەيدۇ",
    "Configures a CardDAV account" : "CardDAV ھېساباتىنى سەپلەيدۇ",
    "Events" : "Events",
    "Untitled task" : "نامسىز ۋەزىپە",
    "Completed on %s" : "% S دا تاماملاندى",
    "Due on %s by %s" : "% S نىڭ سەۋەبىدىن% s",
    "Due on %s" : "% S سەۋەبىدىن",
    "DAV system address book" : "DAV سىستېما ئادرېس دەپتىرى",
    "No outstanding DAV system address book sync." : "مۇنەۋۋەر DAV سىستېمىسى ئادرېس كىتاب ماسقەدەملەش يوق.",
    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "مىسالىڭىزدا 1000 دىن ئارتۇق ئىشلەتكۈچى بار ياكى خاتالىق يۈز بەرگەنلىكى ئۈچۈن DAV سىستېمىسى ئادرېس دەپتىرىنى ماسقەدەملەش تېخى ئىجرا بولمىدى. ئۇنى «occ dav: sync-system-addressbook» دەپ چاقىرىپ قولدا ئىجرا قىلىڭ.",
    "WebDAV endpoint" : "WebDAV ئاخىرقى نۇقتىسى",
    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "تور مۇلازىمېتىرىڭىزنىڭ WebDAV ئارقىلىق ھۆججەت ماسقەدەملىشىگە يول قويۇلغانلىقىنى تەكشۈرەلمىدىڭىز. قولدا تەكشۈرۈپ بېقىڭ.",
    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "تور مۇلازىمېتىرىڭىز ھۆججەتنىڭ ماس قەدەمدە بولۇشىغا يول قويۇلمىدى ، چۈنكى WebDAV كۆرۈنمە يۈزى بۇزۇلغاندەك قىلىدۇ.",
    "Your web server is properly set up to allow file synchronization over WebDAV." : "تور مۇلازىمېتىرىڭىز WebDAV ئارقىلىق ھۆججەت ماسقەدەملەش ئۈچۈن مۇۋاپىق تەڭشەلدى.",
    "Migrated calendar (%1$s)" : "كۆچۈرۈلگەن كالېندار (%1 $ s)",
    "Calendars including events, details and attendees" : "پائالىيەتلەر ، تەپسىلاتلار ۋە قاتناشقۇچىلارنى ئۆز ئىچىگە ئالغان كالېندارلار",
    "Contacts and groups" : "ئالاقىلىشىش ۋە گۇرۇپپىلار",
    "WebDAV" : "WebDAV",
    "Absence saved" : "يوقلۇق ساقلاندى",
    "Failed to save your absence settings" : "يوقلۇقىڭىزنى ساقلىيالمىدى",
    "Absence cleared" : "يوقالغان",
    "Failed to clear your absence settings" : "يوقلۇقىڭىزنى تەڭشىمىدى",
    "First day" : "بىرىنچى كۈنى",
    "Last day (inclusive)" : "ئالدىنقى كۈنى (ئۆز ئىچىگە ئالىدۇ)",
    "Out of office replacement (optional)" : "ئىش ئورنىنى ئالماشتۇرۇش (ئىختىيارىي)",
    "Name of the replacement" : "ئالماشتۇرغۇچىنىڭ ئىسمى",
    "No results." : "ھېچقانداق نەتىجە يوق.",
    "Start typing." : "يېزىشنى باشلاڭ.",
    "Short absence status" : "قىسقا ۋاقىتلىق ھالەت",
    "Long absence Message" : "ئۇزۇن بولمىغان ئۇچۇر",
    "Save" : "ساقلا",
    "Disable absence" : "يوقلۇقىنى چەكلەڭ",
    "Failed to load availability" : "ئىشلىتىشچانلىقىنى يۈكلىيەلمىدى",
    "Saved availability" : "تېجەشلىك",
    "Failed to save availability" : "ئىشلەتكىلى بولمىدى",
    "Time zone:" : "ۋاقىت رايونى:",
    "to" : "to",
    "Delete slot" : "ئورۇننى ئۆچۈرۈڭ",
    "No working hours set" : "خىزمەت ۋاقتى بېكىتىلمىدى",
    "Add slot" : "ئورۇن قوشۇڭ",
    "Weekdays" : "ھەپتە كۈنلىرى",
    "Pick a start time for {dayName}" : "{dayName} نىڭ باشلىنىش ۋاقتىنى تاللاڭ",
    "Pick a end time for {dayName}" : "{dayName} نىڭ ئاخىرقى ۋاقتىنى تاللاڭ",
    "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "بارلىق ئۇقتۇرۇشلارنى ئاۋازسىز قىلىش ئۈچۈن ئىشلەتكۈچى ھالىتىنى ئاپتوماتىك ھالدا «ئاۋارە قىلماڭ» قىلىپ تەڭشەڭ.",
    "Availability" : "ئىشلەتكىلى بولىدۇ",
    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "ئەگەر خىزمەت ۋاقتىڭىزنى تەڭشىسىڭىز ، باشقىلار يىغىن زاكاز قىلغاندا سىزنىڭ ئىشتىن چۈشكەن ۋاقتىڭىزنى كۆرىدۇ.",
    "Absence" : "يوق",
    "Configure your next absence period." : "كېيىنكى يوقلۇق ۋاقتىڭىزنى سەپلەڭ.",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "يەنە {calendarappstoreopen} كالېندار دېتالى {linkclose} ياكى {calendardocopen} نى قاچىلاڭ ئۈستەلئۈستىڭىز ۋە كۆچمە تېلېفونىڭىزنى ئۇلاڭ ↗ {linkclose}.",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "{emailopen} ئېلېكترونلۇق خەت مۇلازىمېتىرى {linkclose} نى مۇۋاپىق تەڭشەشكە كاپالەتلىك قىلىڭ.",
    "Calendar server" : "كالېندار مۇلازىمېتىرى",
    "Send invitations to attendees" : "يىغىنغا قاتناشقۇچىلارغا تەكلىپنامە ئەۋەتىڭ",
    "Automatically generate a birthday calendar" : "تۇغۇلغان كۈن كالېندارىنى ئاپتوماتىك ھاسىل قىلىدۇ",
    "Birthday calendars will be generated by a background job." : "تۇغۇلغان كۈن كالېندارى ئارقا كۆرۈنۈش خىزمىتى ئارقىلىق بارلىققا كېلىدۇ.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "شۇڭلاشقا ئۇلار قوزغىتىلغاندىن كېيىن دەرھال تېپىلمايدۇ ، ئەمما مەلۇم ۋاقىتتىن كېيىن پەيدا بولىدۇ.",
    "Send notifications for events" : "ۋەقەلەرگە ئۇقتۇرۇش ئەۋەتىڭ",
    "Notifications are sent via background jobs, so these must occur often enough." : "ئۇقتۇرۇش ئارقا كۆرۈنۈش خىزمىتى ئارقىلىق ئەۋەتىلىدۇ ، شۇڭا بۇلار چوقۇم يېتەرلىك بولۇشى كېرەك.",
    "Send reminder notifications to calendar sharees as well" : "كالېندار ھەمبەھىرلىرىگىمۇ ئەسكەرتىش ئۇقتۇرۇشى ئەۋەتىڭ",
    "Reminders are always sent to organizers and attendees." : "ئەسكەرتىش ھەمىشە تەشكىللىگۈچىلەر ۋە قاتناشقۇچىلارغا ئەۋەتىلىدۇ.",
    "Enable notifications for events via push" : "ئىتتىرىش ئارقىلىق ۋەقەلەرگە ئۇقتۇرۇشنى قوزغىتىڭ",
    "Cancel" : "بىكار قىلىش",
    "Import" : "ئەكىر",
    "Error while saving settings" : "تەڭشەكلەرنى ساقلاش جەريانىدا خاتالىق",
    "There was an error updating your attendance status." : "قاتنىشىش ھالىتىڭىزنى يېڭىلاشتا خاتالىق كۆرۈلدى.",
    "Please contact the organizer directly." : "تەشكىللىگۈچى بىلەن بىۋاسىتە ئالاقىلىشىڭ.",
    "Are you accepting the invitation?" : "تەكلىپنى قوبۇل قىلامسىز؟",
    "Tentative" : "Tentative",
    "Your attendance was updated successfully." : "سىزنىڭ قاتنىشىشىڭىز مۇۋەپپەقىيەتلىك يېڭىلاندى.",
    "Time:" : "ۋاقىت:",
    "Could not open file" : "ھۆججەت ئاچالمىدى",
    "Invalid chunk name" : "ئىناۋەتسىز",
    "Could not rename part file assembled from chunks" : "بۆلەكلەردىن يىغىلغان قىسمەن ھۆججەتنىڭ نامىنى ئۆزگەرتەلمىدى"
},
"nplurals=2; plural=(n != 1);");
